#!/bin/sh
#------------------------------------------------------------------------------
# /tmp/install.sh - installation file for weavemini services on EIS/FAIR
#
# Copyright (c) 2010-2011 The Eisfair Team, team(at)eisfair(dot)org
#
# Creation   : 2010-11-21 jed
# Last Update: $Id: install.sh 31882 2012-10-16 12:16:05Z jed $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version..
#------------------------------------------------------------------------------

# include eislib etc.
. /var/install/include/eislib
. /var/install/include/check-eisfair-version

module_name='weavemini'
module_webdir='weave_minimal'
apache2file=/etc/config.d/apache2
apache2php5file=/etc/config.d/apache2_php5
sqlbin=/usr/bin/sqlite3

mecho -info "running install.sh ..."

### set directory and file names ###
case ${EISFAIR_SYSTEM} in
    eisfair-1)
        # eisfair-1
        apache_user='wwwrun'
        apache_group='nogroup'
        ;;
    *)
        # default to eisfair-2
        apache_user='www-data'
        apache_group='www-data'
        ;;
esac

# menue entry does not exist - create it
mecho "adding ${module_name} module menu  ..."
/var/install/bin/add-menu -menu "setup.services.menu" "setup.services.${module_name}.menu" "WeaveMini Server"

mecho "extracting weave files ..."

# read Apache2 configuration
. ${apache2file}

web_root="${APACHE2_DOCUMENT_ROOT}/${module_webdir}"

if [ ! -d ${web_root} ]
then
    # create destination directory
    mkdir -p ${web_root}
fi

# extracting server files
tar xzf /tmp/weave_minimal.tgz -C ${web_root}/
rm -f /tmp/weave_minimal.tgz

# remove obsolete files
rm -f ${web_root}/README*
rm -f ${web_root}/create_user
rm -f ${web_root}/weavemini-modify-user.php    # not required anymore since FSyncMS is used

# create empty database if it doesn't exist
if [ ! -f ${web_root}/weave_db ]
then
    cp /usr/share/doc/weavemini/weave_db.EMPTY-DB ${web_root}/weave_db
fi

# import database
if [ -f /var/run/weavemini-export.sql ]
then
    > ${web_root}/weave_db

    mecho "importing weave_db data ..."
    ${sqlbin} ${web_root}/weave_db < /var/run/weavemini-export.sql

    rm -f /var/run/weavemini-export.sql
fi

chown ${apache_user}  ${web_root}/weave_db
chgrp ${apache_group} ${web_root}/weave_db

# checking weave environment
/var/install/bin/weavemini-environment-test

exit 0
