#!/bin/sh
#------------------------------------------------------------------------------
# /tmp/preinstall.sh - pre installation file for weavemini services on EIS/FAIR
#
# Copyright (c) 2010-2012 The Eisfair Team, team(at)eisfair(dot)org
#
# Creation:     2010-11-21 jed
# Last Update:  $Id: preinstall.sh 31881 2012-10-16 12:14:57Z jed $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version..
#------------------------------------------------------------------------------

# file names
module_name='weavemini'
module_webdir='weave_minimal'
deinstallfile=/var/install/deinstall/${module_name}
apache2file=/etc/config.d/apache2
sqlbin=/usr/bin/sqlite3

colecho "running preinstall.sh ..." gn

# check base version
installed_version=`/var/install/bin/check-version base 1.8.7`

case ${installed_version} in
    not-installed|new ) # wrong version
        colecho "required base package v1.8.7 not installed - installation aborted." w rd br
        /var/install/bin/anykey
        exit 1
        ;;
    * ) # installed / old
        ;;
esac

# read eislib
. /var/install/include/eislib

if [ ! -f ${apache2file} ]
then
    mecho -error "required Apache2 package not installed- installation aborted."
    exit 1
else
    installed_version=`/var/install/bin/check-version weavemini 1.0.1`

    case ${installed_version} in
        installed|new ) # previous version
            mecho "exporting weave_db data ..."
            # read Apache2 configuration
            . ${apache2file}

            web_root="${APACHE2_DOCUMENT_ROOT}/${module_webdir}"

            if [ -f ${sqlbin} -a -f ${web_root}/weave_db ]
            then
                # backup database
                /var/install/bin/backup-file --quiet ${web_root}/weave_db 

                # 1. export database
                #
                # 2. insert 'realname' column in table 'users'
                #
                #    OLD: md5 text,                  NEW: md5 text,
                #         primary key (username)          realname text,
                #                                         primary key (username)
                #
                # 3. insert realname from username
                #
                #    OLD: INSERT INTO "users" VALUES('frank','cf96047a35783be0b7a426cf8afed7b0');
                #
                #    NEW: INSERT INTO "users" VALUES('frank','cf96047a35783be0b7a426cf8afed7b0','frank');

#               ${sqlbin} ${web_root}/weave_db .dump | sed -e '/md5 text,$/ {N; s/md5 text,\n primary/md5 text,\n realname text,\n primary/}' -e "/\"users\" VALUES(/ s/('\(.*\)',\(.*\));/('\1',\2,'\1');/g" > /var/run/weavemini-export.sql
                ${sqlbin} ${web_root}/weave_db .dump > /var/run/weavemini-export.sql
            fi
            ;;
        * ) # not-installed / old
            ;;
    esac
fi

# deinstall old software
mecho "deinstalling previously installed software ..."
/var/install/bin/del-package -p ${module_name} update

exit 0
